pub struct HashBasedSigExample { /* private fields */ }Trait Implementations
Sourceimpl ExampleCircuit for HashBasedSigExample
impl ExampleCircuit for HashBasedSigExample
Sourcetype Params = Params
type Params = Params
Circuit parameters that affect the structure of the circuit.
These are typically compile-time constants or bounds.
Sourcetype Instance = Instance
type Instance = Instance
Instance data used to populate the witness.
This represents the actual input values for a specific proof.
Sourcefn build(params: Params, builder: &mut CircuitBuilder) -> Result<Self>
fn build(params: Params, builder: &mut CircuitBuilder) -> Result<Self>
Build the circuit with the given parameters. Read more
Sourcefn populate_witness(
&self,
_instance: Instance,
w: &mut WitnessFiller<'_>,
) -> Result<()>
fn populate_witness( &self, _instance: Instance, w: &mut WitnessFiller<'_>, ) -> Result<()>
Populate witness values for a specific instance. Read more